@@ -144,7 +144,8 @@ class Config(object):
         **If False**::
 
             .. attribute:: attr1
-               :annotation: int
+
+               *int*
 
                Description of `attr1`
 
